@@ -25,23 +25,29 @@
 #include "kcmultidialog.h"
 #include "kcmultidialog_p.h"
 
+#include "kcmoduleqml_p.h"
 #include "kcmoduleproxy.h"
 
+#include <QApplication>
 #include <QDebug>
 #include <QDesktopServices>
+#include <QDesktopWidget>
+#include <QLayout>
 #include <QProcess>
 #include <QPushButton>
-#include <QScrollArea>
 #include <QStringList>
+#include <QStyle>
 #include <QUrl>
 
+#ifndef KCONFIGWIDGETS_NO_KAUTH
 #include <KAuthAction>
 #include <KAuthObjectDecorator>
+#endif
 #include <KGuiItem>
-#include <KIconLoader>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KPageWidgetModel>
+#include <KIconLoader>
 
 bool KCMultiDialogPrivate::resolveChanges(KCModuleProxy *currentProxy)
 {
@@ -80,18 +86,41 @@ bool KCMultiDialogPrivate::resolveChanges(KCModuleProxy *currentProxy)
 void KCMultiDialogPrivate::_k_slotCurrentPageChanged(KPageWidgetItem *current, KPageWidgetItem *previous)
 {
     Q_Q(KCMultiDialog);
-    // qDebug();
+
+
+    KCModuleProxy *currentModule = nullptr;
+    KCModuleProxy *previousModule = nullptr;
+    for (int i = 0; i < modules.count(); ++i) {
+        if (modules[i].item == previous) {
+            previousModule = modules[i].kcm;
+        }
+        if (modules[i].item == current) {
+            currentModule = modules[i].kcm;
+        }
+    }
+
+    // For some reason the KCModuleQml modules handle their own margin internally
+    // to match that we need to adjust the spacing of our page widget
+    // by removing the spacing between the left pane and the edge, and the layout on the right
+    // when we reduce the layout on the right we need to pad the buttons back to match
+
+    // TODO KF6 Fix this situation.
+
+    if (currentModule && currentModule->realModule() && currentModule->realModule()->inherits("KCModuleQml")) {
+        q->pageWidget()->layout()->setSpacing(0);
+        q->buttonBox()->setContentsMargins(q->style()->pixelMetric(QStyle::PM_LayoutLeftMargin),
+                                           0,
+                                           q->style()->pixelMetric(QStyle::PM_LayoutRightMargin),
+                                           q->style()->pixelMetric(QStyle::PM_LayoutBottomMargin));
+    } else {
+        q->buttonBox()->setContentsMargins(0, 0, 0, 0);
+        q->pageWidget()->layout()->setSpacing(q->style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing));
+    }
 
     q->blockSignals(true);
     q->setCurrentPage(previous);
 
-    KCModuleProxy *previousModule = nullptr;
-    for (int i = 0; i < modules.count(); ++i) {
-        if (modules[ i ].item == previous) {
-            previousModule = modules[ i ].kcm;
-            break;
-        }
-    }
+
 
     if (resolveChanges(previousModule)) {
         q->setCurrentPage(current);
@@ -122,16 +151,21 @@ void KCMultiDialogPrivate::_k_clientChanged()
         QPushButton *applyButton = q->buttonBox()->button(QDialogButtonBox::Apply);
         if (applyButton) {
             q->disconnect(applyButton, &QAbstractButton::clicked, q, &KCMultiDialog::slotApplyClicked);
+#ifndef KCONFIGWIDGETS_NO_KAUTH
             delete applyButton->findChild<KAuth::ObjectDecorator *>();
+#endif
             applyButton->setEnabled(change);
         }
 
         QPushButton *okButton = q->buttonBox()->button(QDialogButtonBox::Ok);
         if (okButton) {
             q->disconnect(okButton, &QAbstractButton::clicked, q, &KCMultiDialog::slotOkClicked);
+#ifndef KCONFIGWIDGETS_NO_KAUTH
             delete okButton->findChild<KAuth::ObjectDecorator *>();
+#endif
         }
 
+#ifndef KCONFIGWIDGETS_NO_KAUTH
         if (activeModule->realModule()->needsAuthorization()) {
             if (applyButton) {
                 KAuth::ObjectDecorator *decorator = new KAuth::ObjectDecorator(applyButton);
@@ -157,6 +191,7 @@ void KCMultiDialogPrivate::_k_clientChanged()
                 delete okButton->findChild<KAuth::ObjectDecorator *>();
             }
         }
+#endif
     }
 
     QPushButton *resetButton = q->buttonBox()->button(QDialogButtonBox::Reset);
@@ -189,11 +224,11 @@ void KCMultiDialogPrivate::_k_updateHeader(bool use, const QString &message)
     KCModuleProxy *kcm = qobject_cast<KCModuleProxy *>(item->widget());
 
     if (use) {
-        item->setHeader(QStringLiteral("<b>") + kcm->moduleInfo().comment() + QStringLiteral("</b><br><i>") +
+        item->setHeader(QStringLiteral("<b>") + kcm->moduleInfo().moduleName() + QStringLiteral("</b><br><i>") +
                         message + QStringLiteral("</i>"));
         item->setIcon(KDE::icon(kcm->moduleInfo().icon(), QStringList() << QStringLiteral("dialog-warning")));
     } else {
-        item->setHeader(kcm->moduleInfo().comment());
+        item->setHeader(kcm->moduleInfo().moduleName());
         item->setIcon(QIcon::fromTheme(kcm->moduleInfo().icon()));
     }
 }
@@ -261,9 +296,18 @@ KCMultiDialog::~KCMultiDialog()
 
 void KCMultiDialog::showEvent(QShowEvent *ev)
 {
-    resize(QSize(800, 550));
-    adjustSize();
     KPageDialog::showEvent(ev);
+    adjustSize();
+    /**
+     * adjustSize() relies on sizeHint but is limited to 2/3 of the desktop size
+     * Workaround for https://bugreports.qt.io/browse/QTBUG-3459
+     *
+     * We adjust the size after passing the show event
+     * because otherwise window pos is set to (0,0)
+     */
+    const QSize maxSize = QApplication::desktop()->availableGeometry(pos()).size();
+    resize(qMin(sizeHint().width(), maxSize.width()),
+           qMin(sizeHint().height(), maxSize.height()));
 }
 
 void KCMultiDialog::slotDefaultClicked()
@@ -315,7 +359,7 @@ void KCMultiDialogPrivate::apply()
     Q_Q(KCMultiDialog);
     QStringList updatedComponents;
 
-    foreach (const CreatedModule &module, modules) {
+    for (const CreatedModule &module : qAsConst(modules)) {
         KCModuleProxy *proxy = module.kcm;
 
         if (proxy->changed()) {
@@ -325,7 +369,7 @@ void KCMultiDialogPrivate::apply()
                 * of updated components.
                 */
             const QStringList componentNames = module.componentNames;
-            foreach (const QString &componentName, module.componentNames) {
+            for (const QString &componentName : componentNames) {
                 if (!updatedComponents.contains(componentName)) {
                     updatedComponents.append(componentName);
                 }
@@ -334,7 +378,7 @@ void KCMultiDialogPrivate::apply()
     }
 
     // Send the configCommitted signal for every updated component.
-    foreach (const QString &name, updatedComponents) {
+    for (const QString &name : qAsConst(updatedComponents)) {
         emit q->configCommitted(name.toLatin1());
     }
 
@@ -393,7 +437,7 @@ void KCMultiDialog::closeEvent(QCloseEvent *event)
      * in other situations will lead to "module already loaded in Foo," while to the user
      * doesn't appear so(the dialog is hidden)
      */
-    Q_FOREACH(auto &proxy, d->modules) {
+    for(auto &proxy : qAsConst(d->modules)) {
         proxy.kcm->deleteClient();
     }
 }
@@ -414,6 +458,7 @@ KPageWidgetItem *KCMultiDialog::addModule(const QString &path, const QStringList
 KPageWidgetItem *KCMultiDialog::addModule(const KCModuleInfo &moduleInfo,
         KPageWidgetItem *parentItem, const QStringList &args)
 {
+    Q_D(KCMultiDialog);
     if (!moduleInfo.service()) {
         return nullptr;
     }
@@ -437,15 +482,25 @@ KPageWidgetItem *KCMultiDialog::addModule(const KCModuleInfo &moduleInfo,
     // qDebug() << moduleInfo.moduleName();
     KPageWidgetItem *item = new KPageWidgetItem(moduleScroll, moduleInfo.moduleName());
 
+    KCMultiDialogPrivate::CreatedModule cm;
+    cm.kcm = kcm;
+    cm.item = item;
+    cm.componentNames = moduleInfo.service()->property(QStringLiteral("X-KDE-ParentComponents")).toStringList();
+    d->modules.append(cm);
+
+    if (qobject_cast<KCModuleQml *>(kcm->realModule())) {
+        item->setHeaderVisible(false);
+    }
+
     if (kcm->realModule() && kcm->realModule()->useRootOnlyMessage()) {
         item->setHeader(QStringLiteral("<b>") +
-                moduleInfo.comment() +
+                moduleInfo.moduleName() +
                 QStringLiteral("</b><br><i>") +
                 kcm->realModule()->rootOnlyMessage() +
                 QStringLiteral("</i>"));
         item->setIcon(KDE::icon(moduleInfo.icon(), QStringList() << QStringLiteral("dialog-warning")));
     } else {
-        item->setHeader(moduleInfo.comment());
+        item->setHeader(moduleInfo.moduleName());
         item->setIcon(QIcon::fromTheme(moduleInfo.icon()));
     }
     item->setProperty("_k_weight", moduleInfo.weight());
@@ -497,13 +552,6 @@ KPageWidgetItem *KCMultiDialog::addModule(const KCModuleInfo &moduleInfo,
     connect(kcm, SIGNAL(changed(bool)), this, SLOT(_k_clientChanged()));
     connect(kcm->realModule(), SIGNAL(rootOnlyMessageChanged(bool,QString)), this, SLOT(_k_updateHeader(bool,QString)));
 
-    Q_D(KCMultiDialog);
-    KCMultiDialogPrivate::CreatedModule cm;
-    cm.kcm = kcm;
-    cm.item = item;
-    cm.componentNames = moduleInfo.service()->property(QStringLiteral("X-KDE-ParentComponents")).toStringList();
-    d->modules.append(cm);
-
     if (d->modules.count() == 1 || updateCurrentPage) {
         setCurrentPage(item);
         d->_k_clientChanged();
