@@ -19,7 +19,6 @@
 
 #include "ksettings/pluginpage.h"
 #include "kpluginselector.h"
-#include <QLayout>
 #include "ksettings/dispatcher.h"
 #include <kaboutdata.h>
 
@@ -30,11 +29,10 @@ class PluginPagePrivate
 {
 public:
     PluginPagePrivate()
-        : selwid(nullptr)
     {
     }
 
-    KPluginSelector *selwid;
+    KPluginSelector *selwid = nullptr;
     void _k_reparseConfiguration(const QByteArray &a);
 };
 
